pub struct StrictMembership<T, S>{
inner: Arc<RwLock<Inner<T, S>>>,
epoch_height: BlockNumber,
}Fields
inner: Arc<RwLock<Inner<T, S>>>epoch_height: BlockNumberTrait Implementations
Sourceimpl<T, S> Clone for StrictMembership<T, S>
impl<T, S> Clone for StrictMembership<T, S>
Sourcefn clone(&self) -> StrictMembership<T, S>
fn clone(&self) -> StrictMembership<T, S>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T, S> Debug for StrictMembership<T, S>
impl<T, S> Debug for StrictMembership<T, S>
Sourceimpl<T, S> Membership<T> for StrictMembership<T, S>
impl<T, S> Membership<T> for StrictMembership<T, S>
type Error = StrictMembershipError
Sourcetype Snapshot = StrictEpochSnapshot<T, S>
type Snapshot = StrictEpochSnapshot<T, S>
A consistent per-epoch view, returned by
Self::snapshot.Sourcetype NonEpochSnapshot = StrictNonEpochSnapshot<T, S>
type NonEpochSnapshot = StrictNonEpochSnapshot<T, S>
A consistent pre-epoch view, returned by
Self::non_epoch_snapshot.Sourcefn snapshot(&self, epoch: EpochNumber) -> Option<Self::Snapshot>
fn snapshot(&self, epoch: EpochNumber) -> Option<Self::Snapshot>
Capture a consistent per-epoch view. Read more
Sourcefn non_epoch_snapshot(&self) -> Self::NonEpochSnapshot
fn non_epoch_snapshot(&self) -> Self::NonEpochSnapshot
Capture a consistent pre-epoch view.
Sourcefn add_drb_result(&self, e: EpochNumber, drb: DrbResult)
fn add_drb_result(&self, e: EpochNumber, drb: DrbResult)
Called to notify the Membership when a new DRB result has been calculated.
Sourcefn first_epoch(&self) -> Option<EpochNumber>
fn first_epoch(&self) -> Option<EpochNumber>
Get first epoch if epochs are enabled,
None otherwise.Sourcefn set_first_epoch(&self, e: EpochNumber, initial_drb_result: DrbResult)
fn set_first_epoch(&self, e: EpochNumber, initial_drb_result: DrbResult)
Called to notify the Membership that Epochs are enabled.
Implementations should copy the pre-epoch stake table into epoch and epoch+1
when this is called. The value of initial_drb_result should be used for DRB
calculations for epochs (epoch+1) and earlier.
Sourceasync fn add_epoch_root(&self, hdr: T::BlockHeader) -> Result<(), Self::Error>
async fn add_epoch_root(&self, hdr: T::BlockHeader) -> Result<(), Self::Error>
Handles notifications that a new epoch root has been created.
Sourceasync fn get_epoch_root(&self, e: EpochNumber) -> Result<Leaf2<T>, Self::Error>
async fn get_epoch_root(&self, e: EpochNumber) -> Result<Leaf2<T>, Self::Error>
Gets the validated block header and epoch number of the epoch root
at the given block height.
Sourceasync fn get_epoch_drb(&self, e: EpochNumber) -> Result<DrbResult, Self::Error>
async fn get_epoch_drb(&self, e: EpochNumber) -> Result<DrbResult, Self::Error>
Gets the DRB result for the given epoch.
Sourcefn add_da_committee(
&self,
first_epoch: EpochNumber,
committee: Vec<PeerConfig<T>>,
)
fn add_da_committee( &self, first_epoch: EpochNumber, committee: Vec<PeerConfig<T>>, )
Register a DA committee that takes effect starting at
first_epoch.Sourcefn highest_known_epoch(&self) -> Option<EpochNumber>
fn highest_known_epoch(&self) -> Option<EpochNumber>
Get the highest epoch for which a stake table is currently in memory,
or
None if no stake tables are loaded. Used at startup to find the
point from which to walk forward catching up missing epochs.Sourceimpl<T, S> TestableMembership<T> for StrictMembership<T, S>
impl<T, S> TestableMembership<T> for StrictMembership<T, S>
Sourcefn new(
quorum_members: Vec<PeerConfig<T>>,
da_members: Vec<PeerConfig<T>>,
_public_key: T::SignatureKey,
epoch_height: u64,
) -> Self
fn new( quorum_members: Vec<PeerConfig<T>>, da_members: Vec<PeerConfig<T>>, _public_key: T::SignatureKey, epoch_height: u64, ) -> Self
Construct a membership for tests.
Sourcefn set_leaf_fetcher(
&self,
network: Arc<dyn LeafFetcherNetwork<T>>,
storage: TestStorage<T>,
public_key: T::SignatureKey,
channel: Receiver<Event<T>>,
)
fn set_leaf_fetcher( &self, network: Arc<dyn LeafFetcherNetwork<T>>, storage: TestStorage<T>, public_key: T::SignatureKey, channel: Receiver<Event<T>>, )
Install a fully wired leaf fetcher. Must be called before any code
path that triggers catchup (
get_epoch_root / get_epoch_drb).Auto Trait Implementations
impl<T, S> Freeze for StrictMembership<T, S>
impl<T, S> !RefUnwindSafe for StrictMembership<T, S>
impl<T, S> Send for StrictMembership<T, S>
impl<T, S> Sync for StrictMembership<T, S>
impl<T, S> Unpin for StrictMembership<T, S>
impl<T, S> UnsafeUnpin for StrictMembership<T, S>
impl<T, S> !UnwindSafe for StrictMembership<T, S>